@@ -1,8 +1,10 @@
 from .apis import *
+from .apis.api_config import *
 from .channels import *
 from .dns import *
 from .mini_sdk import *
 from .pb2 import *
+from .pkg_tool import *
 from .tool import *
 
 name = "mini"
@@ -13,29 +15,27 @@ __all__ = [
     'pb2',
     'dns',
     'mini_sdk',
+    'RobotType',
+    'ServicePlatform',
+    'LanType',
     'get_device_by_name',
     'get_device_list',
     'connect',
     'release',
-    'register_msg_handler',
-    'unregister_msg_handler',
     'WiFiDevice',
     'WiFiDeviceListener',
-    'GetWiFiDeviceListListener',
     'install_py_pkg',
     'uninstall_py_pkg',
     'run_py_pkg',
     'query_py_pkg',
     'list_py_pkg',
     'setup_py_pkg',
-    'PCProgramCmdId',
-    'PCPyCmdId',
+    'switch_adb',
     'COMMON',
     'SPEECH',
     'VISION',
     'MessageHeader',
     'Message',
-    'AbstractMsgHandler',
     'CONTENT',
     'MOTION',
     'EXPRESS',
@@ -54,7 +54,6 @@ __all__ = [
     'RobotActionType',
     'RobotAudioRecordControlType',
     'RobotExpressionType',
-    'RobotBehaviorControlType',
     'MouthLampColor',
     'MouthLampMode',
     'RobotPosture',
@@ -64,5 +63,6 @@ __all__ = [
     'TTSControlType',
     'AudioStorageType',
     'AudioSearchType',
-    'service_type'
+    'service_type',
+    'upload_script',
 ]
